]> cygwin.com Git - cygwin-apps/setup.git/blobdiff - desktop.h
Also run stratum 'z' perpetual preremove scripts
[cygwin-apps/setup.git] / desktop.h
index 8c14a1d6b5387a8562cd7d5b4e745f1e89baf0b0..71436e81ae6610417dd602eab0e128d738ae57ee 100644 (file)
--- a/desktop.h
+++ b/desktop.h
@@ -1,41 +1,45 @@
-#ifndef CINSTALL_DESKTOP_H\r
-#define CINSTALL_DESKTOP_H\r
-\r
-/*\r
- * Copyright (c) 2001, Gary R. Van Sickle.\r
- *\r
- *     This program is free software; you can redistribute it and/or modify\r
- *     it under the terms of the GNU General Public License as published by\r
- *     the Free Software Foundation; either version 2 of the License, or\r
- *     (at your option) any later version.\r
- *\r
- *     A copy of the GNU General Public License can be found at\r
- *     http://www.gnu.org/\r
- *\r
- * Written by Gary R. Van Sickle <g.r.vansickle@worldnet.att.net>\r
- *\r
- */\r
-\r
-// This is the header for the DesktopSetupPage class.  Allows selection\r
-// of "create desktop icon" and "add to start menu".\r
-\r
-#include "proppage.h"\r
-\r
-class DesktopSetupPage:public PropertyPage\r
-{\r
-public:\r
-  DesktopSetupPage ()\r
-  {\r
-  };\r
-  virtual ~ DesktopSetupPage ()\r
-  {\r
-  };\r
-\r
-  bool Create ();\r
-\r
-  virtual void OnInit ();\r
-  virtual bool OnFinish ();\r
-  virtual long OnBack ();\r
-};\r
-\r
-#endif // CINSTALL_DESKTOP_H\r
+/*
+ * Copyright (c) 2001, Gary R. Van Sickle.
+ *
+ *     This program is free software; you can redistribute it and/or modify
+ *     it under the terms of the GNU General Public License as published by
+ *     the Free Software Foundation; either version 2 of the License, or
+ *     (at your option) any later version.
+ *
+ *     A copy of the GNU General Public License can be found at
+ *     http://www.gnu.org/
+ *
+ * Written by Gary R. Van Sickle <g.r.vansickle@worldnet.att.net>
+ *
+ */
+
+#ifndef SETUP_DESKTOP_H
+#define SETUP_DESKTOP_H
+
+// This is the header for the DesktopSetupPage class.  Allows selection
+// of "create desktop icon" and "add to start menu".
+
+#include "proppage.h"
+
+// WM_APP through WM_APP+7: see threebar.h
+#define WM_APP_UNATTENDED_FINISH WM_APP+8
+
+class DesktopSetupPage:public PropertyPage
+{
+public:
+  DesktopSetupPage ();
+  virtual ~ DesktopSetupPage ()
+  {
+  };
+
+  bool Create ();
+
+  virtual void OnInit ();
+  virtual void OnActivate ();
+  virtual bool OnFinish ();
+  virtual long OnBack ();
+  virtual long OnUnattended ();
+  virtual bool OnMessageApp (UINT uMsg, WPARAM wParam, LPARAM lParam);
+};
+
+#endif /* SETUP_DESKTOP_H */
This page took 0.025873 seconds and 5 git commands to generate.